@@ -1,6 +1,6 @@
 package Pg::PQ;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use 5.010001;
 use strict;
@@ -139,7 +139,7 @@ These are the methods available from the class Pg::PQ::Conn:
 
 =item $dbc = Pg::PQ::Conn->new(%conninfo)
 
-I<(wraps PQconnectdb)>
+X<new>I<(wraps PQconnectdb)>
 
 This method creates a new Pg::PQ::Conn object and connects to the
 database defined by the parameters given as a string (C<$conninfo>) or
@@ -408,19 +408,19 @@ L<http://www.postgresql.org/docs/9.0/interactive/libpq-connect.html>.
 
 =item $dbc = Pg::PQ::Conn->start($conninfo)
 
-I<(wraps PQconnectStart)>
+X<start>I<(wraps PQconnectStart)>
 
 This method is similar to L</new> but returns inmediately, without
 waiting for the network connection to the database or the protocol
 handshake to be completed.
 
-Combined with L</pollStart> described below allows to establish
+Combined with L</connectPoll> described below allows to establish
 database connections asynchronously (see L</Non-blocking connecting to
 the database>).
 
 =item $poll_status = $dbc->connectPoll
 
-I<(wraps PQconnectPoll)>
+X<connectPoll>I<(wraps PQconnectPoll)>
 
 This method returns the polling status when connecting asynchronously
 to a database. Returns any of the L</pgres_polling> constants (see
@@ -532,9 +532,9 @@ Is reported if the connection is bad.
 
 PostgreSQL documentation contains the following warning:
 
-   Caution: C<transactionStatus> will give incorrect results when
-   using a PostgreSQL 7.3 server that has the parameter autocommit set
-   to off. The server-side autocommit feature has been deprecated and
+   Caution: transactionStatus will give incorrect results when using a
+   PostgreSQL 7.3 server that has the parameter autocommit set to
+   off. The server-side autocommit feature has been deprecated and
    does not exist in later server versions.
 
 =item $dbc->parameterStatus
@@ -563,7 +563,7 @@ Parameters reported as of the current release include:
   application_name was not reported by releases before 9.0.
 
 Note that C<server_version>, C<server_encoding> and
-C<integer_datetimes> cannot change after startup.
+C<integer_datetimes> can not change after startup.
 
 Pre-3.0-protocol servers do not report parameter settings, but libpq
 includes logic to obtain values for C<server_version> and
@@ -607,8 +607,8 @@ are not shown). Zero is returned if the connection is bad.
 
 =item $dbc->errorMessage
 
-Returns the error message most recently generated by an operation on
-the connection.
+X<errorMessage>Returns the error message most recently generated by an
+operation on the connection.
 
 Nearly all libpq functions will set a message for C<errorMessage> if
 they fail. Error messages can be multiline.
@@ -652,16 +652,16 @@ connection attempt to detect whether the server demanded a password.
 
 =item $dbc->finish
 
-Closes the connection to the server and frees the underlaying libpq
-PGconn data structure. This method is automatically called by
+X<finish>Closes the connection to the server and frees the underlaying
+libpq PGconn data structure. This method is automatically called by
 C<DESTROY> so usually there is no need to call it explicitly.
 
 =item $dbc->reset
 
-This function will close the connection to the server and attempt to
-reestablish a new connection to the same server, using all the same
-parameters previously used. This might be useful for error recovery if
-a working connection is lost.
+X<reset>This function will close the connection to the server and
+attempt to reestablish a new connection to the same server, using all
+the same parameters previously used. This might be useful for error
+recovery if a working connection is lost.
 
 =item $dbc->resetStart
 
@@ -684,8 +684,8 @@ connection using C<connectPoll>.
 
 =item $dbc->trace($fh)
 
-Enables tracing of the client/server communication to a debugging file
-handle. For instance:
+X<trace>Enables tracing of the client/server communication to a
+debugging file handle. For instance:
 
   $dbc->trace(*STDERR);
 
@@ -749,7 +749,7 @@ C<DEALLOCATE> statement can be used for that purpose.
 
 =item $res = $dbc->execQueryPrepared($name => @args)
 
-I<(wraps PQexecPrepared)>
+X<execQueryPrepared>I<(wraps PQexecPrepared)>
 
 This method sends a request to execute a prepared statement with given
 parameters, and waits for the result.
@@ -768,8 +768,8 @@ a prepared statement is given instead of a query string.
 
 =item $res = $dbc->describePrepared($name)
 
-Submits a request to obtain information about the specified prepared
-statement, and waits for completion.
+X<describePrepared>Submits a request to obtain information about the
+specified prepared statement, and waits for completion.
 
 C<describePrepared> allows an application to obtain information about
 a previously prepared statement. It is supported only in protocol 3.0
@@ -781,7 +781,7 @@ Pg::PQ::Result object with status C<PGRES_COMMAND_OK> is returned. The
 functions L</nParams> and L</paramType> can be applied to this
 Pg::PQ::Result object to obtain information about the parameters of
 the prepared statement, and the methods L</nFields>, L</fName>,
-L<f/Type>, etc provide information about the result columns (if any)
+L</fType>, etc provide information about the result columns (if any)
 of the statement.
 
 =item $res = $dbc->describePortal($portalName)
@@ -814,7 +814,7 @@ about the failure).
 After successfully calling C<sendQuery>, call L</result> one or
 more times to obtain the results.
 
-C<sendQuery cannot be called again on the same connection until
+C<sendQuery> can not be called again on the same connection until
 C<result> has returned C<undef>, indicating that the command is done.
 
 =item $ok = $dbc->sendPrepare($name => $query)
@@ -1293,6 +1293,15 @@ Otherwise, this function returns C<undef>. This function will also
 return C<undef> if the table affected by the C<INSERT> statement does
 not contain OIDs.
 
+=item $n = $res->nParams
+
+X<nParams>Return the number of parameters on the prepared query.
+
+=item $oid = $res->paramType($ix)
+
+X<paramType>Returns the type of the parameter at the given index on a
+prepared query.
+
 =head2 Pg::PQ::Cancel class
 
 The cancel object is an artifact provided by the C libpq library to
@@ -1332,6 +1341,8 @@ The following constants can be imported from this module:
 
 =item :pgres_polling
 
+X<pgres_polling>
+
   PGRES_POLLING_FAILED
   PGRES_POLLING_READING
   PGRES_POLLING_WRITING
@@ -1476,7 +1487,7 @@ these documented values. An application might do something like this:
 The C<connect_timeout> connection parameter is ignored when using
 C<start> and C<connectPoll>; it is the application's responsibility to
 decide whether an excessive amount of time has elapsed. Otherwise,
-C<tart> followed by a C<connectPoll> loop is equivalent to
+C<start> followed by a C<connectPoll> loop is equivalent to
 C<new>.
 
 =head3 Non-blocking quering the database
@@ -1503,8 +1514,8 @@ A client that uses C<sendQuery>/C<result> can also attempt to cancel a
 command that is still being processed by the server (see Section 31.5
 of the PostgreSQL documentation). But regardless of the return value
 of C<cancel>, the application must continue with the normal
-result-reading sequence using C<result. A successful cancellation will
-simply cause the command to terminate sooner than it would have
+result-reading sequence using C<result>. A successful cancellation
+will simply cause the command to terminate sooner than it would have
 otherwise.
 
 By using the functions described above, it is possible to avoid
@@ -1516,7 +1527,7 @@ probable if the application sends data via C<COPY IN>, however).
 
 To prevent this possibility and achieve completely nonblocking
 database operation, the nonblocking mode has to be activated for
-the session using C<$dbc->nonBlocking(1)>.
+the session using C<$dbc-E<gt>nonBlocking(1)>.
 
 After sending any command or data on a nonblocking connection, call
 C<flush>. If it returns 1, wait for the socket to be write-ready and
